@@ -107,9 +107,21 @@ model.normal <- function(network){
     }
     
     if(!is.null(mean.A) & !is.null(prec.A)){
+      
       code <- paste0(code,
                      "\n\tA ~ dnorm(mean.A, prec.A)",
-                     "\n\tfor(k in 1:", ntreat, ") { T[k] <- A + d[k] }")
+                     "\n\tfor(k in 1:", ntreat, ") { T[k] <- A + d[k]")
+      
+      if(!is.null(covariate) & !is.null(Z)){
+        for(i in 1:dim(covariate)[2]){
+          code <- paste0(code, " + (beta", i, "[k]- beta", i, "[1]) * (", Z[i], " - mx", i, ")")
+        }
+      }
+      
+      if(baseline != "none" & !is.null(Z_bl)){
+        code <- paste0(code, " + (b_bl[k] - b_bl[1]) * (", Z_bl, " - mx_bl)")
+      }
+      code <- paste0(code, " }")
     }
     
     return(code)
@@ -211,9 +223,23 @@ model.binomial <- function(network)
     }
     
     if(!is.null(mean.A) & !is.null(prec.A)){
+      
       code <- paste0(code,
                      "\n\tA ~ dnorm(mean.A, prec.A)",
-                     "\n\tfor(k in 1:", ntreat, ") { logit(T[k]) <- A + d[k] }",
+                     "\n\tfor(k in 1:", ntreat, ") { logit(T[k]) <- A + d[k]")
+      
+      if(!is.null(covariate) & !is.null(Z)){
+        for(i in 1:dim(covariate)[2]){
+          code <- paste0(code, " + (beta", i, "[k]- beta", i, "[1]) * (", Z[i], " - mx", i, ")")
+        }
+      }
+
+      if(baseline != "none" & !is.null(Z_bl)){
+        code <- paste0(code, " + (b_bl[k] - b_bl[1]) * (", Z_bl, " - mx_bl)")
+      }
+      code <- paste0(code, " }")
+      
+      code <- paste0(code,
                      "\n\tfor(k in 1:", ntreat, ") {",
                      "\n\t\tfor(kk in (k+1):", ntreat, ") {",
                      "\n\t\tNNT[kk,k] <- 1/(T[kk] - T[k])",
